@@ -128,7 +128,8 @@ class CensysAPIBase:
 
     @backoff.on_predicate(
         backoff.runtime,
-        predicate=lambda r: r.status_code == 429 and r.headers.get("Retry-After"),
+        predicate=lambda r: r.status_code in (429, 503)
+        and r.headers.get("Retry-After"),
         value=lambda r: int(r.headers.get("Retry-After", 0)),
     )
     def _call_method(
